@@ -6,12 +6,15 @@ Boxer - system deployment ninja tricks
 
 =cut
 
+use strict;
+use warnings;
+
 use 5.01;
 
 use Role::Commons -all;
 
 our $AUTHORITY = 'cpan:JONASS';
-our $VERSION   = '0.002';
+our $VERSION   = '0.004';
 
 1;
 
@@ -36,7 +39,7 @@ Jonas Smedegaard E<lt>dr@jones.dkE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013 by Jonas Smedegaard.
+This software is copyright (c) 2013-2014 by Jonas Smedegaard.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
